@@ -3,11 +3,12 @@ import os
 import re
 import copy
 
-
 from idebug import *
 
 
+
 __all__ =[
+    'get_filenames',
     'get_dirs',
     'get_filepaths',
     'open_file',
@@ -15,6 +16,16 @@ __all__ =[
 ]
 
 
+
+def get_filenames(path):
+    fnames = []
+    with os.scandir(path) as it:
+        for entry in it:
+            if not entry.name.startswith('.') and entry.is_file():
+                fnames.append(entry.name)
+    return sorted(fnames)
+
+
 def get_dirs(path, alldepth=False):
     all_dirs = []
     for root, dirs, files in os.walk(top=path, topdown=True):
@@ -55,7 +66,6 @@ def open_file(filepath):
 
 
 def _makedirs(filepath):
-    """내부 사용용."""
     try:
         os.makedirs(os.path.dirname(filepath))
     except Exception as e:
