@@ -1,10 +1,18 @@
 # -*- coding: utf-8 -*-
 import numpy as np
 
-
 from idebug import *
 
 
+
+__all__ = [
+    'fraction',
+    'relative_change',
+    'rate',
+    'dist_ratio',
+]
+
+
 def fraction(numerator, denominator):
     # 나누기
     try:
